%global prerelease rc1

%if 0%{?fedora}
%global _with_python3 1
%endif

%if 0%{?rhel}
%global py2_prefix python
%else
%global py2_prefix python2
%endif

%global azure_sdk_min_version 3.0.0

%global srcname azure-storage

%global common_summary Microsoft Azure Storage Library for Python
%global common_description This project provides a client library in Python that makes it easy to consume\
Microsoft Azure Storage services.

Name:           python-%{srcname}
Version:        1.2.0
Release:        0.3.%{prerelease}%{?dist}
Summary:        %{common_summary}

License:        ASL 2.0
URL:            https://github.com/Azure/azure-storage-python/
Source0:        https://github.com/Azure/azure-storage-python/archive/v%{version}%{?prerelease}-common/%{srcname}-%{version}%{?prerelease}.tar.gz
# Fix install_requires option, for EPEL especially
Patch0:         %{name}-1.2.0-build.patch

BuildRequires:  %{py2_prefix}-setuptools
BuildRequires:  %{py2_prefix}-devel
BuildRequires:  %{py2_prefix}-azure-sdk >= %{azure_sdk_min_version}
# Needed to build documentation
BuildRequires:  %{py2_prefix}-cryptography
BuildRequires:  %{py2_prefix}-dateutil
BuildRequires:  %{py2_prefix}-futures
BuildRequires:  %{py2_prefix}-pip
BuildRequires:  %{py2_prefix}-pytest
BuildRequires:  %{py2_prefix}-requests
BuildRequires:  %{py2_prefix}-sphinx
BuildRequires:  %{py2_prefix}-vcrpy
%if 0%{?_with_python3}
BuildRequires:  python3-devel
BuildRequires:  python3-azure-sdk >= %{azure_sdk_min_version}
BuildRequires:  python3-cryptography
BuildRequires:  python3-dateutil
BuildRequires:  python3-pytest
BuildRequires:  python3-requests
BuildRequires:  python3-vcrpy
%endif
BuildArch:      noarch

%description
%{common_description}


%package -n python2-%{srcname}
Summary:        %{common_summary}
Requires:       %{py2_prefix}-azure-sdk >= %{azure_sdk_min_version}
Requires:       %{py2_prefix}-cryptography
Requires:       %{py2_prefix}-dateutil
Requires:       %{py2_prefix}-futures
Requires:       %{py2_prefix}-requests
%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{common_description}


# Python 3 subpackage is disabled in EPEL due to missing dependencies
%if 0%{?_with_python3}
%package -n python3-%{srcname}
Summary:        %{common_summary}
Requires:       python3-azure-sdk >= %{azure_sdk_min_version}
Requires:       python3-cryptography
Requires:       python3-dateutil
Requires:       python3-requests
%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
%{common_description}
%endif


%package doc
Summary:        Documentation for %{name}

%description doc
%{common_description}

This package provides documentation for %{name}.


%prep
%autosetup -p0 -n azure-storage-python-%{version}%{?prerelease}-common


%build
for package in azure-storage-nspkg azure-storage-common azure-storage-blob azure-storage-file azure-storage-queue; do
    pushd $package
    %py2_build
    %{?_with_python3:%py3_build}
    popd
done

# Build documentation
%make_build -C doc/ html


%install
for package in azure-storage-nspkg azure-storage-common azure-storage-blob azure-storage-file azure-storage-queue; do
    pushd $package
    %py2_install
    %{?_with_python3:%py3_install}
    popd
done

rm doc/_build/html/.buildinfo

# Drop bits already provided by the python*-azure-sdk packages
rm $RPM_BUILD_ROOT%{python2_sitelib}/azure/__init__.*
%if 0%{?_with_python3}
rm $RPM_BUILD_ROOT%{python3_sitelib}/azure/__init__.*
rm -r $RPM_BUILD_ROOT%{python3_sitelib}/azure/__pycache__/
%endif


%check
export PYTHONPATH=azure-storage-blob/:azure-storage-common/:azure-storage-file/:azure-storage-nspkg/:azure-storage-queue/
python2 -m pytest
%{?_with_python3:python3 -m pytest}



%files -n python2-%{srcname}
%doc BreakingChanges.md ChangeLog.md README.rst
%license LICENSE.txt
%{python2_sitelib}/*


%if 0%{?_with_python3}
%files -n python3-%{srcname}
%doc BreakingChanges.md ChangeLog.md README.rst
%license LICENSE.txt
%{python3_sitelib}/*
%endif


%files doc
%doc doc/_build/html/
%license LICENSE.txt


%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.0-0.3.rc1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 1.2.0-0.2.rc1
- Rebuilt for Python 3.7

* Tue May 29 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.2.0-1
- Update to 1.2.0rc1
- Re-enable tests

* Tue Apr 10 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.1.0-2
- Drop all files already provided by python-azure-sdk packages

* Wed Apr 04 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.1.0-1
- Update to 1.1.0

* Tue Mar 13 2018 Iryna Shcherbina <ishcherb@redhat.com> - 0.36.0-3
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.36.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Sep 05 2017 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.36.0-1
- Update to 0.36.0

* Sun Sep 03 2017 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.35.1-2
- Use parallel make to build documentation
- Move documentation to a subpackage

* Wed Aug 09 2017 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.35.1-1
- Update to 0.35.1

* Fri Jun 16 2017 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.34.3-1
- Update to 0.34.3

* Tue Feb 21 2017 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.34.0-1
- Update to 0.34.0

* Fri Oct 14 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.33.0-3
- Add missing dependency on python-cryptography
- Remove unneeded BuildRequires on python-six
- Add patch to remove unused imports to cryptography.hazmat.primitives.keywrap
  (unavailable in RHEL7)

* Wed Oct 12 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.33.0-2
- Add missing dependency on python-futures

* Wed Oct 05 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.33.0-1
- Update to 0.33.0
- Build documentation

* Thu Jul 21 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.32.0-2
- Disable tests by default (a valid Azure subscription is necessary to run them)

* Thu May 26 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.32.0-1
- Update to 0.32.0

* Sun May 01 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.31.0-1
- Update to 0.31.0

* Mon Feb 29 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.30.0-1
- Update to 0.30.0
- Improve macros for Python 3 subpackage

* Wed Jan 13 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.20.3-1
- Initial RPM release
